<?php
/*
Plugin Name: Custom Minimalist Backoffice
Description: Plugin que torna o backoffice minimalista, ocultando menus e atalhos desnecessários, alterando as cores, limitando acesso a recursos para utilizadores não administradores, e substituindo "WooCommerce" por "Loja".
Version: 2.4
Author: Seu Nome
*/

// Função para substituir a palavra "WooCommerce" por "Loja"
function custom_replace_woocommerce_text($translated_text, $text, $domain) {
    if (is_admin()) {
        // Substituir "WooCommerce" por "Loja"
        $translated_text = str_replace('WooCommerce', 'Loja', $translated_text);
    }
    return $translated_text;
}
add_filter('gettext', 'custom_replace_woocommerce_text', 20, 3);

// Função para personalizar as permissões do painel de administração
function custom_backoffice_permissions() {
    // Obter o utilizador atual
    $user = wp_get_current_user();

    // Se o utilizador for o webmaster (com papel de 'administrator'), não limitar o acesso
    if (in_array('administrator', (array) $user->roles)) {
        return;
    }

    // Remover menus desnecessários para todos que não são administradores
    remove_menu_page('tools.php');                 // Ferramentas
    remove_menu_page('options-general.php');       // Definições
    remove_menu_page('plugins.php');               // Plugins
    remove_menu_page('edit.php?post_type=page');   // Páginas
    remove_menu_page('themes.php');                // Aparência
    remove_menu_page('customize.php');             // Personalizar
    remove_menu_page('update-core.php');           // Atualizações
    remove_menu_page('vc-welcome');                // WPBakery Page Builder
    remove_menu_page('feather-login-designer');    // Feather Login Designer
    remove_menu_page('samipe_options');            // Samipe Options
    remove_menu_page('edit.php?post_type=elementor_library'); // Modelos (Elementor)
    remove_submenu_page('woocommerce', 'wc-admin'); // WooCommerce Dashboard
    remove_submenu_page('woocommerce', 'wc-admin&path=/extensions'); // WooCommerce Extensões
    remove_submenu_page('woocommerce', 'wc-admin&path=/analytics/overview'); // WooCommerce Estado
    remove_menu_page('about.php');                 // Sobre o WordPress
    remove_menu_page('nasa-theme-options');        // Opções do tema Nasa
    remove_menu_page('wc-admin&path=%2Fextensions'); // WooCommerce Extensões
    remove_menu_page('moloni');                    // Moloni integração
    remove_menu_page('vc-general');                // WPBakery Page Builder (geral)
    remove_menu_page('plpb_feather-login-page-dashboard'); // Feather Login Designer dashboard
}
add_action('admin_menu', 'custom_backoffice_permissions', 999);

// Função para remover a barra de ferramentas (admin bar) superior para todos que não são administradores
function custom_hide_admin_bar() {
    if (!current_user_can('administrator')) {
        add_filter('show_admin_bar', '__return_false'); // Esconder a barra de ferramentas
    }
}
add_action('after_setup_theme', 'custom_hide_admin_bar');

// Função para esconder o ícone do WordPress e links associados da barra de ferramentas
function custom_remove_admin_bar_links() {
    global $wp_admin_bar;
    
    $wp_admin_bar->remove_menu('wp-logo'); // Ícone do WordPress
    $wp_admin_bar->remove_menu('about');   // Sobre o WordPress
    $wp_admin_bar->remove_menu('wporg');   // WordPress.org
    $wp_admin_bar->remove_menu('documentation'); // Documentação
    $wp_admin_bar->remove_menu('support-forums'); // Fóruns de suporte
    $wp_admin_bar->remove_menu('feedback'); // Feedback
    $wp_admin_bar->remove_menu('view-site'); // Ver site
    $wp_admin_bar->remove_menu('updates');   // Atualizações
    $wp_admin_bar->remove_node('new-page'); // Remover atalho para adicionar nova página
    $wp_admin_bar->remove_node('elementor_library'); // Se existir um atalho global do Elementor Library
    $wp_admin_bar->remove_node('post-new-elementor_library'); // Remover atalho para criar novo Elementor Library
    $wp_admin_bar->remove_node('post-8003-elementor'); // Remover o atalho específico para o post com ID 8003 no Elementor
    remove_filter('admin_footer_text', 'core_update_footer'); // Remove a seção de "Agradecimentos" no rodapé
}
add_action('wp_before_admin_bar_render', 'custom_remove_admin_bar_links');

// Remover agradecimentos "Obrigado por criar com WordPress" do rodapé
function custom_remove_footer_text() {
    return '';
}
add_filter('admin_footer_text', 'custom_remove_footer_text');

// Função para ajustar capacidades de utilizadores que não são administradores
function custom_backoffice_role_capabilities() {
    $shop_manager = get_role('shop_manager');
    $editor = get_role('editor');

    // Capacidades adicionais para permitir acesso ao submenu "Clientes" do WooCommerce
    $capabilities = [
        'list_users',              // Listar usuários
        'create_users',            // Criar novos usuários
        'edit_users',              // Editar usuários
        'delete_users',            // Apagar usuários
        'promote_users',           // Promover/demover usuários
        'manage_woocommerce',      // Gerenciar configurações do WooCommerce
        'view_woocommerce_reports', // Ver relatórios do WooCommerce
        'edit_posts',              // Editar posts
        'edit_others_posts',       // Editar posts de outros
        'edit_published_posts',    // Editar posts publicados
        'publish_posts',           // Publicar posts
        'edit_products',           // Editar produtos WooCommerce
        'publish_products',        // Publicar produtos WooCommerce
        'edit_published_products', // Editar produtos publicados
        'upload_files',            // Fazer upload de arquivos
        'edit_comments',           // Editar comentários
        'moderate_comments',       // Moderar comentários
        'view_customers',          // Ver o submenu "Clientes" no WooCommerce
    ];

    // Adiciona as capacidades ao gerente da loja
    if ($shop_manager) {
        foreach ($capabilities as $capability) {
            $shop_manager->add_cap($capability);
        }
    }

    // Adiciona as capacidades ao editor
    if ($editor) {
        foreach ($capabilities as $capability) {
            $editor->add_cap($capability);
        }
    }
}
add_action('init', 'custom_backoffice_role_capabilities');

// Remover atalhos de ajuda e "Visualizar" na barra de ferramentas e no backoffice
function custom_remove_help_tabs() {
    $screen = get_current_screen();
    $screen->remove_help_tabs(); // Remove a aba de ajuda
}
add_action('admin_head', 'custom_remove_help_tabs');

// Esconder atalhos e ajuda da barra de ferramentas
function custom_remove_screen_options() {
    return false;
}
add_filter('screen_options_show_screen', 'custom_remove_screen_options');

// Ocultar atualizações do WordPress para utilizadores não administradores
function custom_hide_updates() {
    if (!current_user_can('administrator')) {
        remove_action('admin_notices', 'update_nag', 3); // Oculta notificações de atualização
    }
}
add_action('admin_menu', 'custom_hide_updates');

// Alterar cores do backoffice via CSS
function custom_backoffice_custom_colors() {
    echo '
    <style>
        #wpadminbar, #adminmenu, #adminmenu .wp-submenu, #adminmenuwrap, #adminmenuback {
            background-color: #1a1a1a; /* Cor de fundo principal */
        }
        #adminmenu a {
            color: #f0f0f0; /* Cor dos links do menu */
        }
        #adminmenu .wp-has-current-submenu .wp-submenu .wp-submenu-head, 
        #adminmenu .wp-menu-arrow, 
        #adminmenu .wp-menu-open .wp-menu-arrow, 
        #adminmenu li.wp-has-current-submenu a.wp-has-current-submenu, 
        #adminmenu li.current a.menu-top {
            background-color: #282828; /* Cor de submenu e seleção */
            color: #00a0d2; /* Cor de links selecionados */
        }
        #adminmenu .wp-menu-name {
            color: #f0f0f0; /* Cor do texto do menu */
        }
        /* Esconder atualizações de tema */
        .update-nag, .theme-update, #wp-admin-bar-updates {
            display: none;
        }
    </style>
    ';
}
add_action('admin_head', 'custom_backoffice_custom_colors');
